
#ifndef INCIDENCEEDITOR_EXPORT_H
#define INCIDENCEEDITOR_EXPORT_H

#ifdef INCIDENCEEDITOR_STATIC_DEFINE
#  define INCIDENCEEDITOR_EXPORT
#  define INCIDENCEEDITOR_NO_EXPORT
#else
#  ifndef INCIDENCEEDITOR_EXPORT
#    ifdef KPim6IncidenceEditor_EXPORTS
        /* We are building this library */
#      define INCIDENCEEDITOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define INCIDENCEEDITOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef INCIDENCEEDITOR_NO_EXPORT
#    define INCIDENCEEDITOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef INCIDENCEEDITOR_DECL_DEPRECATED
#  define INCIDENCEEDITOR_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef INCIDENCEEDITOR_DECL_DEPRECATED_EXPORT
#  define INCIDENCEEDITOR_DECL_DEPRECATED_EXPORT INCIDENCEEDITOR_EXPORT INCIDENCEEDITOR_DECL_DEPRECATED
#endif

#ifndef INCIDENCEEDITOR_DECL_DEPRECATED_NO_EXPORT
#  define INCIDENCEEDITOR_DECL_DEPRECATED_NO_EXPORT INCIDENCEEDITOR_NO_EXPORT INCIDENCEEDITOR_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef INCIDENCEEDITOR_NO_DEPRECATED
#    define INCIDENCEEDITOR_NO_DEPRECATED
#  endif
#endif
#include <incidenceeditor_version.h>

#define INCIDENCEEDITOR_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(INCIDENCEEDITOR_NO_DEPRECATED)
#  undef INCIDENCEEDITOR_DEPRECATED
#  define INCIDENCEEDITOR_DEPRECATED_EXPORT INCIDENCEEDITOR_EXPORT
#  define INCIDENCEEDITOR_DEPRECATED_NO_EXPORT INCIDENCEEDITOR_NO_EXPORT
#elif defined(INCIDENCEEDITOR_NO_DEPRECATED_WARNINGS)
#  define INCIDENCEEDITOR_DEPRECATED
#  define INCIDENCEEDITOR_DEPRECATED_EXPORT INCIDENCEEDITOR_EXPORT
#  define INCIDENCEEDITOR_DEPRECATED_NO_EXPORT INCIDENCEEDITOR_NO_EXPORT
#else
#  define INCIDENCEEDITOR_DEPRECATED INCIDENCEEDITOR_DECL_DEPRECATED
#  define INCIDENCEEDITOR_DEPRECATED_EXPORT INCIDENCEEDITOR_DECL_DEPRECATED_EXPORT
#  define INCIDENCEEDITOR_DEPRECATED_NO_EXPORT INCIDENCEEDITOR_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define INCIDENCEEDITOR_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define INCIDENCEEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef INCIDENCEEDITOR_NO_DEPRECATED
#  define INCIDENCEEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT INCIDENCEEDITOR_VERSION
#endif
#ifdef INCIDENCEEDITOR_NO_DEPRECATED_WARNINGS
#  define INCIDENCEEDITOR_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef INCIDENCEEDITOR_DEPRECATED_WARNINGS_SINCE
#  ifdef INCIDENCEEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define INCIDENCEEDITOR_DEPRECATED_WARNINGS_SINCE INCIDENCEEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define INCIDENCEEDITOR_DEPRECATED_WARNINGS_SINCE INCIDENCEEDITOR_VERSION
#  endif
#endif

#ifndef INCIDENCEEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define INCIDENCEEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef INCIDENCEEDITOR_DEPRECATED
#  define INCIDENCEEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > INCIDENCEEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define INCIDENCEEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* INCIDENCEEDITOR_EXPORT_H */
